from make87_messages_ros2.rolling.builtin_interfaces.msg import duration_pb2 as _duration_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class AudioNote(_message.Message):
    __slots__ = ["frequency", "max_runtime"]
    FREQUENCY_FIELD_NUMBER: _ClassVar[int]
    MAX_RUNTIME_FIELD_NUMBER: _ClassVar[int]
    frequency: int
    max_runtime: _duration_pb2.Duration
    def __init__(self, frequency: _Optional[int] = ..., max_runtime: _Optional[_Union[_duration_pb2.Duration, _Mapping]] = ...) -> None: ...



from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class TimTM2(_message.Message):
    __slots__ = ["ch", "flags", "rising_edge_count", "wn_r", "wn_f", "tow_ms_r", "tow_sub_ms_r", "tow_ms_f", "tow_sub_ms_f", "acc_est"]
    CH_FIELD_NUMBER: _ClassVar[int]
    FLAGS_FIELD_NUMBER: _ClassVar[int]
    RISING_EDGE_COUNT_FIELD_NUMBER: _ClassVar[int]
    WN_R_FIELD_NUMBER: _ClassVar[int]
    WN_F_FIELD_NUMBER: _ClassVar[int]
    TOW_MS_R_FIELD_NUMBER: _ClassVar[int]
    TOW_SUB_MS_R_FIELD_NUMBER: _ClassVar[int]
    TOW_MS_F_FIELD_NUMBER: _ClassVar[int]
    TOW_SUB_MS_F_FIELD_NUMBER: _ClassVar[int]
    ACC_EST_FIELD_NUMBER: _ClassVar[int]
    ch: int
    flags: int
    rising_edge_count: int
    wn_r: int
    wn_f: int
    tow_ms_r: int
    tow_sub_ms_r: int
    tow_ms_f: int
    tow_sub_ms_f: int
    acc_est: int
    def __init__(self, ch: _Optional[int] = ..., flags: _Optional[int] = ..., rising_edge_count: _Optional[int] = ..., wn_r: _Optional[int] = ..., wn_f: _Optional[int] = ..., tow_ms_r: _Optional[int] = ..., tow_sub_ms_r: _Optional[int] = ..., tow_ms_f: _Optional[int] = ..., tow_sub_ms_f: _Optional[int] = ..., acc_est: _Optional[int] = ...) -> None: ...



from make87_messages.core import header_pb2 as _header_pb2
from make87_messages_ros2.humble.std_msgs.msg import header_pb2 as _header_pb2_1
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Joy(_message.Message):
    __slots__ = ["header", "ros2_header", "axes", "buttons"]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    ROS2_HEADER_FIELD_NUMBER: _ClassVar[int]
    AXES_FIELD_NUMBER: _ClassVar[int]
    BUTTONS_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    ros2_header: _header_pb2_1.Header
    axes: _containers.RepeatedScalarFieldContainer[float]
    buttons: _containers.RepeatedScalarFieldContainer[int]
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., ros2_header: _Optional[_Union[_header_pb2_1.Header, _Mapping]] = ..., axes: _Optional[_Iterable[float]] = ..., buttons: _Optional[_Iterable[int]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/sick_safetyscanners2_interfaces/msg/application_data.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.rolling.sick_safetyscanners2_interfaces.msg import application_inputs_pb2 as make87__messages__ros2_dot_rolling_dot_sick__safetyscanners2__interfaces_dot_msg_dot_application__inputs__pb2
from make87_messages_ros2.rolling.sick_safetyscanners2_interfaces.msg import application_outputs_pb2 as make87__messages__ros2_dot_rolling_dot_sick__safetyscanners2__interfaces_dot_msg_dot_application__outputs__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nWmake87_messages_ros2/rolling/sick_safetyscanners2_interfaces/msg/application_data.proto\x12@make87_messages_ros2.rolling.sick_safetyscanners2_interfaces.msg\x1aYmake87_messages_ros2/rolling/sick_safetyscanners2_interfaces/msg/application_inputs.proto\x1aZmake87_messages_ros2/rolling/sick_safetyscanners2_interfaces/msg/application_outputs.proto\"\xdd\x01\n\x0f\x41pplicationData\x12\x63\n\x06inputs\x18\x01 \x01(\x0b\x32S.make87_messages_ros2.rolling.sick_safetyscanners2_interfaces.msg.ApplicationInputs\x12\x65\n\x07outputs\x18\x02 \x01(\x0b\x32T.make87_messages_ros2.rolling.sick_safetyscanners2_interfaces.msg.ApplicationOutputsb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.sick_safetyscanners2_interfaces.msg.application_data_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_APPLICATIONDATA']._serialized_start=341
  _globals['_APPLICATIONDATA']._serialized_end=562
# @@protoc_insertion_point(module_scope)



from make87_messages_ros2.rolling.std_msgs.msg import header_pb2 as _header_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class VehicleStateMsg2(_message.Message):
    __slots__ = ["header", "fsm_yaw_rate_valid", "fsm_yaw_rate", "can_vehicle_index_4fa", "fsm_vehicle_velocity", "can_steering_whl_angle_qf", "fsm_vehicle_velocity_valid", "can_steering_whl_angle"]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    FSM_YAW_RATE_VALID_FIELD_NUMBER: _ClassVar[int]
    FSM_YAW_RATE_FIELD_NUMBER: _ClassVar[int]
    CAN_VEHICLE_INDEX_4FA_FIELD_NUMBER: _ClassVar[int]
    FSM_VEHICLE_VELOCITY_FIELD_NUMBER: _ClassVar[int]
    CAN_STEERING_WHL_ANGLE_QF_FIELD_NUMBER: _ClassVar[int]
    FSM_VEHICLE_VELOCITY_VALID_FIELD_NUMBER: _ClassVar[int]
    CAN_STEERING_WHL_ANGLE_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    fsm_yaw_rate_valid: bool
    fsm_yaw_rate: float
    can_vehicle_index_4fa: int
    fsm_vehicle_velocity: float
    can_steering_whl_angle_qf: bool
    fsm_vehicle_velocity_valid: bool
    can_steering_whl_angle: float
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., fsm_yaw_rate_valid: bool = ..., fsm_yaw_rate: _Optional[float] = ..., can_vehicle_index_4fa: _Optional[int] = ..., fsm_vehicle_velocity: _Optional[float] = ..., can_steering_whl_angle_qf: bool = ..., fsm_vehicle_velocity_valid: bool = ..., can_steering_whl_angle: _Optional[float] = ...) -> None: ...



from make87_messages.core import header_pb2 as _header_pb2
from make87_messages_ros2.humble.builtin_interfaces.msg import duration_pb2 as _duration_pb2
from make87_messages_ros2.humble.geometry_msgs.msg import pose_stamped_pb2 as _pose_stamped_pb2
from make87_messages_ros2.humble.moveit_msgs.msg import constraints_pb2 as _constraints_pb2
from make87_messages_ros2.humble.moveit_msgs.msg import robot_state_pb2 as _robot_state_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class PositionIKRequest(_message.Message):
    __slots__ = ["header", "group_name", "robot_state", "constraints", "avoid_collisions", "ik_link_name", "pose_stamped", "ik_link_names", "pose_stamped_vector", "timeout"]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    GROUP_NAME_FIELD_NUMBER: _ClassVar[int]
    ROBOT_STATE_FIELD_NUMBER: _ClassVar[int]
    CONSTRAINTS_FIELD_NUMBER: _ClassVar[int]
    AVOID_COLLISIONS_FIELD_NUMBER: _ClassVar[int]
    IK_LINK_NAME_FIELD_NUMBER: _ClassVar[int]
    POSE_STAMPED_FIELD_NUMBER: _ClassVar[int]
    IK_LINK_NAMES_FIELD_NUMBER: _ClassVar[int]
    POSE_STAMPED_VECTOR_FIELD_NUMBER: _ClassVar[int]
    TIMEOUT_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    group_name: str
    robot_state: _robot_state_pb2.RobotState
    constraints: _constraints_pb2.Constraints
    avoid_collisions: bool
    ik_link_name: str
    pose_stamped: _pose_stamped_pb2.PoseStamped
    ik_link_names: _containers.RepeatedScalarFieldContainer[str]
    pose_stamped_vector: _containers.RepeatedCompositeFieldContainer[_pose_stamped_pb2.PoseStamped]
    timeout: _duration_pb2.Duration
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., group_name: _Optional[str] = ..., robot_state: _Optional[_Union[_robot_state_pb2.RobotState, _Mapping]] = ..., constraints: _Optional[_Union[_constraints_pb2.Constraints, _Mapping]] = ..., avoid_collisions: bool = ..., ik_link_name: _Optional[str] = ..., pose_stamped: _Optional[_Union[_pose_stamped_pb2.PoseStamped, _Mapping]] = ..., ik_link_names: _Optional[_Iterable[str]] = ..., pose_stamped_vector: _Optional[_Iterable[_Union[_pose_stamped_pb2.PoseStamped, _Mapping]]] = ..., timeout: _Optional[_Union[_duration_pb2.Duration, _Mapping]] = ...) -> None: ...



from make87_messages.core import header_pb2 as _header_pb2
from make87_messages_ros2.humble.std_msgs.msg import header_pb2 as _header_pb2_1
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class UserInputADAS(_message.Message):
    __slots__ = ["header", "ros2_header", "btn_cc_on", "btn_cc_off", "btn_cc_on_off", "btn_cc_set_inc", "btn_cc_set_dec", "btn_cc_res", "btn_cc_cncl", "btn_cc_res_cncl", "btn_acc_gap_inc", "btn_acc_gap_dec", "btn_lka_on", "btn_lka_off", "btn_lka_on_off"]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    ROS2_HEADER_FIELD_NUMBER: _ClassVar[int]
    BTN_CC_ON_FIELD_NUMBER: _ClassVar[int]
    BTN_CC_OFF_FIELD_NUMBER: _ClassVar[int]
    BTN_CC_ON_OFF_FIELD_NUMBER: _ClassVar[int]
    BTN_CC_SET_INC_FIELD_NUMBER: _ClassVar[int]
    BTN_CC_SET_DEC_FIELD_NUMBER: _ClassVar[int]
    BTN_CC_RES_FIELD_NUMBER: _ClassVar[int]
    BTN_CC_CNCL_FIELD_NUMBER: _ClassVar[int]
    BTN_CC_RES_CNCL_FIELD_NUMBER: _ClassVar[int]
    BTN_ACC_GAP_INC_FIELD_NUMBER: _ClassVar[int]
    BTN_ACC_GAP_DEC_FIELD_NUMBER: _ClassVar[int]
    BTN_LKA_ON_FIELD_NUMBER: _ClassVar[int]
    BTN_LKA_OFF_FIELD_NUMBER: _ClassVar[int]
    BTN_LKA_ON_OFF_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    ros2_header: _header_pb2_1.Header
    btn_cc_on: bool
    btn_cc_off: bool
    btn_cc_on_off: bool
    btn_cc_set_inc: bool
    btn_cc_set_dec: bool
    btn_cc_res: bool
    btn_cc_cncl: bool
    btn_cc_res_cncl: bool
    btn_acc_gap_inc: bool
    btn_acc_gap_dec: bool
    btn_lka_on: bool
    btn_lka_off: bool
    btn_lka_on_off: bool
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., ros2_header: _Optional[_Union[_header_pb2_1.Header, _Mapping]] = ..., btn_cc_on: bool = ..., btn_cc_off: bool = ..., btn_cc_on_off: bool = ..., btn_cc_set_inc: bool = ..., btn_cc_set_dec: bool = ..., btn_cc_res: bool = ..., btn_cc_cncl: bool = ..., btn_cc_res_cncl: bool = ..., btn_acc_gap_inc: bool = ..., btn_acc_gap_dec: bool = ..., btn_lka_on: bool = ..., btn_lka_off: bool = ..., btn_lka_on_off: bool = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/humble/moveit_msgs/msg/motion_plan_request.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages.core import header_pb2 as make87__messages_dot_core_dot_header__pb2
from make87_messages_ros2.humble.moveit_msgs.msg import constraints_pb2 as make87__messages__ros2_dot_humble_dot_moveit__msgs_dot_msg_dot_constraints__pb2
from make87_messages_ros2.humble.moveit_msgs.msg import generic_trajectory_pb2 as make87__messages__ros2_dot_humble_dot_moveit__msgs_dot_msg_dot_generic__trajectory__pb2
from make87_messages_ros2.humble.moveit_msgs.msg import robot_state_pb2 as make87__messages__ros2_dot_humble_dot_moveit__msgs_dot_msg_dot_robot__state__pb2
from make87_messages_ros2.humble.moveit_msgs.msg import trajectory_constraints_pb2 as make87__messages__ros2_dot_humble_dot_moveit__msgs_dot_msg_dot_trajectory__constraints__pb2
from make87_messages_ros2.humble.moveit_msgs.msg import workspace_parameters_pb2 as make87__messages__ros2_dot_humble_dot_moveit__msgs_dot_msg_dot_workspace__parameters__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nEmake87_messages_ros2/humble/moveit_msgs/msg/motion_plan_request.proto\x12+make87_messages_ros2.humble.moveit_msgs.msg\x1a!make87_messages/core/header.proto\x1a=make87_messages_ros2/humble/moveit_msgs/msg/constraints.proto\x1a\x44make87_messages_ros2/humble/moveit_msgs/msg/generic_trajectory.proto\x1a=make87_messages_ros2/humble/moveit_msgs/msg/robot_state.proto\x1aHmake87_messages_ros2/humble/moveit_msgs/msg/trajectory_constraints.proto\x1a\x46make87_messages_ros2/humble/moveit_msgs/msg/workspace_parameters.proto\"\xe7\x06\n\x11MotionPlanRequest\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12^\n\x14workspace_parameters\x18\x02 \x01(\x0b\x32@.make87_messages_ros2.humble.moveit_msgs.msg.WorkspaceParameters\x12L\n\x0bstart_state\x18\x03 \x01(\x0b\x32\x37.make87_messages_ros2.humble.moveit_msgs.msg.RobotState\x12R\n\x10goal_constraints\x18\x04 \x03(\x0b\x32\x38.make87_messages_ros2.humble.moveit_msgs.msg.Constraints\x12R\n\x10path_constraints\x18\x05 \x01(\x0b\x32\x38.make87_messages_ros2.humble.moveit_msgs.msg.Constraints\x12\x62\n\x16trajectory_constraints\x18\x06 \x01(\x0b\x32\x42.make87_messages_ros2.humble.moveit_msgs.msg.TrajectoryConstraints\x12^\n\x16reference_trajectories\x18\x07 \x03(\x0b\x32>.make87_messages_ros2.humble.moveit_msgs.msg.GenericTrajectory\x12\x13\n\x0bpipeline_id\x18\x08 \x01(\t\x12\x12\n\nplanner_id\x18\t \x01(\t\x12\x12\n\ngroup_name\x18\n \x01(\t\x12\x1d\n\x15num_planning_attempts\x18\x0b \x01(\x05\x12\x1d\n\x15\x61llowed_planning_time\x18\x0c \x01(\x01\x12#\n\x1bmax_velocity_scaling_factor\x18\r \x01(\x01\x12\'\n\x1fmax_acceleration_scaling_factor\x18\x0e \x01(\x01\x12$\n\x1c\x63\x61rtesian_speed_limited_link\x18\x0f \x01(\t\x12\x1b\n\x13max_cartesian_speed\x18\x10 \x01(\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.humble.moveit_msgs.msg.motion_plan_request_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_MOTIONPLANREQUEST']._serialized_start=496
  _globals['_MOTIONPLANREQUEST']._serialized_end=1367
# @@protoc_insertion_point(module_scope)



from make87_messages_ros2.jazzy.gazebo_msgs.msg import ode_physics_pb2 as _ode_physics_pb2
from make87_messages_ros2.jazzy.geometry_msgs.msg import vector3_pb2 as _vector3_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class SetPhysicsPropertiesRequest(_message.Message):
    __slots__ = ["time_step", "max_update_rate", "gravity", "ode_config"]
    TIME_STEP_FIELD_NUMBER: _ClassVar[int]
    MAX_UPDATE_RATE_FIELD_NUMBER: _ClassVar[int]
    GRAVITY_FIELD_NUMBER: _ClassVar[int]
    ODE_CONFIG_FIELD_NUMBER: _ClassVar[int]
    time_step: float
    max_update_rate: float
    gravity: _vector3_pb2.Vector3
    ode_config: _ode_physics_pb2.ODEPhysics
    def __init__(self, time_step: _Optional[float] = ..., max_update_rate: _Optional[float] = ..., gravity: _Optional[_Union[_vector3_pb2.Vector3, _Mapping]] = ..., ode_config: _Optional[_Union[_ode_physics_pb2.ODEPhysics, _Mapping]] = ...) -> None: ...

class SetPhysicsPropertiesResponse(_message.Message):
    __slots__ = ["success", "status_message"]
    SUCCESS_FIELD_NUMBER: _ClassVar[int]
    STATUS_MESSAGE_FIELD_NUMBER: _ClassVar[int]
    success: bool
    status_message: str
    def __init__(self, success: bool = ..., status_message: _Optional[str] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/moveit_msgs/srv/servo_command_type.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nCmake87_messages_ros2/jazzy/moveit_msgs/srv/servo_command_type.proto\x12*make87_messages_ros2.jazzy.moveit_msgs.srv\"/\n\x17ServoCommandTypeRequest\x12\x14\n\x0c\x63ommand_type\x18\x01 \x01(\x05\"+\n\x18ServoCommandTypeResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.moveit_msgs.srv.servo_command_type_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_SERVOCOMMANDTYPEREQUEST']._serialized_start=115
  _globals['_SERVOCOMMANDTYPEREQUEST']._serialized_end=162
  _globals['_SERVOCOMMANDTYPERESPONSE']._serialized_start=164
  _globals['_SERVOCOMMANDTYPERESPONSE']._serialized_end=207
# @@protoc_insertion_point(module_scope)



from make87_messages.core import header_pb2 as _header_pb2
from make87_messages_ros2.humble.rmf_traffic_msgs.msg import negotiation_forfeit_pb2 as _negotiation_forfeit_pb2
from make87_messages_ros2.humble.rmf_traffic_msgs.msg import negotiation_proposal_pb2 as _negotiation_proposal_pb2
from make87_messages_ros2.humble.rmf_traffic_msgs.msg import negotiation_rejection_pb2 as _negotiation_rejection_pb2
from make87_messages_ros2.humble.rmf_traffic_msgs.msg import negotiation_status_pb2 as _negotiation_status_pb2
from make87_messages_ros2.humble.rmf_traffic_msgs.msg import negotiation_tree_node_pb2 as _negotiation_tree_node_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class NegotiationState(_message.Message):
    __slots__ = ["header", "status", "tree", "orphan_proposals", "orphan_rejections", "orphan_forfeits"]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    STATUS_FIELD_NUMBER: _ClassVar[int]
    TREE_FIELD_NUMBER: _ClassVar[int]
    ORPHAN_PROPOSALS_FIELD_NUMBER: _ClassVar[int]
    ORPHAN_REJECTIONS_FIELD_NUMBER: _ClassVar[int]
    ORPHAN_FORFEITS_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    status: _negotiation_status_pb2.NegotiationStatus
    tree: _containers.RepeatedCompositeFieldContainer[_negotiation_tree_node_pb2.NegotiationTreeNode]
    orphan_proposals: _containers.RepeatedCompositeFieldContainer[_negotiation_proposal_pb2.NegotiationProposal]
    orphan_rejections: _containers.RepeatedCompositeFieldContainer[_negotiation_rejection_pb2.NegotiationRejection]
    orphan_forfeits: _containers.RepeatedCompositeFieldContainer[_negotiation_forfeit_pb2.NegotiationForfeit]
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., status: _Optional[_Union[_negotiation_status_pb2.NegotiationStatus, _Mapping]] = ..., tree: _Optional[_Iterable[_Union[_negotiation_tree_node_pb2.NegotiationTreeNode, _Mapping]]] = ..., orphan_proposals: _Optional[_Iterable[_Union[_negotiation_proposal_pb2.NegotiationProposal, _Mapping]]] = ..., orphan_rejections: _Optional[_Iterable[_Union[_negotiation_rejection_pb2.NegotiationRejection, _Mapping]]] = ..., orphan_forfeits: _Optional[_Iterable[_Union[_negotiation_forfeit_pb2.NegotiationForfeit, _Mapping]]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/autoware_planning_msgs/msg/lanelet_segment.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.autoware_planning_msgs.msg import lanelet_primitive_pb2 as make87__messages__ros2_dot_jazzy_dot_autoware__planning__msgs_dot_msg_dot_lanelet__primitive__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nKmake87_messages_ros2/jazzy/autoware_planning_msgs/msg/lanelet_segment.proto\x12\x35make87_messages_ros2.jazzy.autoware_planning_msgs.msg\x1aMmake87_messages_ros2/jazzy/autoware_planning_msgs/msg/lanelet_primitive.proto\"\xd3\x01\n\x0eLaneletSegment\x12\x64\n\x13preferred_primitive\x18\x01 \x01(\x0b\x32G.make87_messages_ros2.jazzy.autoware_planning_msgs.msg.LaneletPrimitive\x12[\n\nprimitives\x18\x02 \x03(\x0b\x32G.make87_messages_ros2.jazzy.autoware_planning_msgs.msg.LaneletPrimitiveb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.autoware_planning_msgs.msg.lanelet_segment_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_LANELETSEGMENT']._serialized_start=214
  _globals['_LANELETSEGMENT']._serialized_end=425
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/autoware_planning_msgs/msg/lanelet_primitive.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nOmake87_messages_ros2/rolling/autoware_planning_msgs/msg/lanelet_primitive.proto\x12\x37make87_messages_ros2.rolling.autoware_planning_msgs.msg\"6\n\x10LaneletPrimitive\x12\n\n\x02id\x18\x01 \x01(\x03\x12\x16\n\x0eprimitive_type\x18\x02 \x01(\tb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.autoware_planning_msgs.msg.lanelet_primitive_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_LANELETPRIMITIVE']._serialized_start=140
  _globals['_LANELETPRIMITIVE']._serialized_end=194
# @@protoc_insertion_point(module_scope)



from make87_messages_ros2.rolling.septentrio_gnss_driver.msg import block_header_pb2 as _block_header_pb2
from make87_messages_ros2.rolling.std_msgs.msg import header_pb2 as _header_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class INSNavGeod(_message.Message):
    __slots__ = ["header", "block_header", "gnss_mode", "error", "info", "gnss_age", "latitude", "longitude", "height", "undulation", "accuracy", "latency", "datum", "sb_list", "latitude_std_dev", "longitude_std_dev", "height_std_dev", "latitude_longitude_cov", "latitude_height_cov", "longitude_height_cov", "heading", "pitch", "roll", "heading_std_dev", "pitch_std_dev", "roll_std_dev", "heading_pitch_cov", "heading_roll_cov", "pitch_roll_cov", "ve", "vn", "vu", "ve_std_dev", "vn_std_dev", "vu_std_dev", "ve_vn_cov", "ve_vu_cov", "vn_vu_cov"]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    BLOCK_HEADER_FIELD_NUMBER: _ClassVar[int]
    GNSS_MODE_FIELD_NUMBER: _ClassVar[int]
    ERROR_FIELD_NUMBER: _ClassVar[int]
    INFO_FIELD_NUMBER: _ClassVar[int]
    GNSS_AGE_FIELD_NUMBER: _ClassVar[int]
    LATITUDE_FIELD_NUMBER: _ClassVar[int]
    LONGITUDE_FIELD_NUMBER: _ClassVar[int]
    HEIGHT_FIELD_NUMBER: _ClassVar[int]
    UNDULATION_FIELD_NUMBER: _ClassVar[int]
    ACCURACY_FIELD_NUMBER: _ClassVar[int]
    LATENCY_FIELD_NUMBER: _ClassVar[int]
    DATUM_FIELD_NUMBER: _ClassVar[int]
    SB_LIST_FIELD_NUMBER: _ClassVar[int]
    LATITUDE_STD_DEV_FIELD_NUMBER: _ClassVar[int]
    LONGITUDE_STD_DEV_FIELD_NUMBER: _ClassVar[int]
    HEIGHT_STD_DEV_FIELD_NUMBER: _ClassVar[int]
    LATITUDE_LONGITUDE_COV_FIELD_NUMBER: _ClassVar[int]
    LATITUDE_HEIGHT_COV_FIELD_NUMBER: _ClassVar[int]
    LONGITUDE_HEIGHT_COV_FIELD_NUMBER: _ClassVar[int]
    HEADING_FIELD_NUMBER: _ClassVar[int]
    PITCH_FIELD_NUMBER: _ClassVar[int]
    ROLL_FIELD_NUMBER: _ClassVar[int]
    HEADING_STD_DEV_FIELD_NUMBER: _ClassVar[int]
    PITCH_STD_DEV_FIELD_NUMBER: _ClassVar[int]
    ROLL_STD_DEV_FIELD_NUMBER: _ClassVar[int]
    HEADING_PITCH_COV_FIELD_NUMBER: _ClassVar[int]
    HEADING_ROLL_COV_FIELD_NUMBER: _ClassVar[int]
    PITCH_ROLL_COV_FIELD_NUMBER: _ClassVar[int]
    VE_FIELD_NUMBER: _ClassVar[int]
    VN_FIELD_NUMBER: _ClassVar[int]
    VU_FIELD_NUMBER: _ClassVar[int]
    VE_STD_DEV_FIELD_NUMBER: _ClassVar[int]
    VN_STD_DEV_FIELD_NUMBER: _ClassVar[int]
    VU_STD_DEV_FIELD_NUMBER: _ClassVar[int]
    VE_VN_COV_FIELD_NUMBER: _ClassVar[int]
    VE_VU_COV_FIELD_NUMBER: _ClassVar[int]
    VN_VU_COV_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    block_header: _block_header_pb2.BlockHeader
    gnss_mode: int
    error: int
    info: int
    gnss_age: int
    latitude: float
    longitude: float
    height: float
    undulation: float
    accuracy: int
    latency: int
    datum: int
    sb_list: int
    latitude_std_dev: float
    longitude_std_dev: float
    height_std_dev: float
    latitude_longitude_cov: float
    latitude_height_cov: float
    longitude_height_cov: float
    heading: float
    pitch: float
    roll: float
    heading_std_dev: float
    pitch_std_dev: float
    roll_std_dev: float
    heading_pitch_cov: float
    heading_roll_cov: float
    pitch_roll_cov: float
    ve: float
    vn: float
    vu: float
    ve_std_dev: float
    vn_std_dev: float
    vu_std_dev: float
    ve_vn_cov: float
    ve_vu_cov: float
    vn_vu_cov: float
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., block_header: _Optional[_Union[_block_header_pb2.BlockHeader, _Mapping]] = ..., gnss_mode: _Optional[int] = ..., error: _Optional[int] = ..., info: _Optional[int] = ..., gnss_age: _Optional[int] = ..., latitude: _Optional[float] = ..., longitude: _Optional[float] = ..., height: _Optional[float] = ..., undulation: _Optional[float] = ..., accuracy: _Optional[int] = ..., latency: _Optional[int] = ..., datum: _Optional[int] = ..., sb_list: _Optional[int] = ..., latitude_std_dev: _Optional[float] = ..., longitude_std_dev: _Optional[float] = ..., height_std_dev: _Optional[float] = ..., latitude_longitude_cov: _Optional[float] = ..., latitude_height_cov: _Optional[float] = ..., longitude_height_cov: _Optional[float] = ..., heading: _Optional[float] = ..., pitch: _Optional[float] = ..., roll: _Optional[float] = ..., heading_std_dev: _Optional[float] = ..., pitch_std_dev: _Optional[float] = ..., roll_std_dev: _Optional[float] = ..., heading_pitch_cov: _Optional[float] = ..., heading_roll_cov: _Optional[float] = ..., pitch_roll_cov: _Optional[float] = ..., ve: _Optional[float] = ..., vn: _Optional[float] = ..., vu: _Optional[float] = ..., ve_std_dev: _Optional[float] = ..., vn_std_dev: _Optional[float] = ..., vu_std_dev: _Optional[float] = ..., ve_vn_cov: _Optional[float] = ..., ve_vu_cov: _Optional[float] = ..., vn_vu_cov: _Optional[float] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/rosapi_msgs/srv/topics_for_type.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n@make87_messages_ros2/jazzy/rosapi_msgs/srv/topics_for_type.proto\x12*make87_messages_ros2.jazzy.rosapi_msgs.srv\"$\n\x14TopicsForTypeRequest\x12\x0c\n\x04type\x18\x01 \x01(\t\"\'\n\x15TopicsForTypeResponse\x12\x0e\n\x06topics\x18\x01 \x03(\tb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.rosapi_msgs.srv.topics_for_type_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_TOPICSFORTYPEREQUEST']._serialized_start=112
  _globals['_TOPICSFORTYPEREQUEST']._serialized_end=148
  _globals['_TOPICSFORTYPERESPONSE']._serialized_start=150
  _globals['_TOPICSFORTYPERESPONSE']._serialized_end=189
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/humble/moveit_msgs/msg/position_ik_request.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages.core import header_pb2 as make87__messages_dot_core_dot_header__pb2
from make87_messages_ros2.humble.builtin_interfaces.msg import duration_pb2 as make87__messages__ros2_dot_humble_dot_builtin__interfaces_dot_msg_dot_duration__pb2
from make87_messages_ros2.humble.geometry_msgs.msg import pose_stamped_pb2 as make87__messages__ros2_dot_humble_dot_geometry__msgs_dot_msg_dot_pose__stamped__pb2
from make87_messages_ros2.humble.moveit_msgs.msg import constraints_pb2 as make87__messages__ros2_dot_humble_dot_moveit__msgs_dot_msg_dot_constraints__pb2
from make87_messages_ros2.humble.moveit_msgs.msg import robot_state_pb2 as make87__messages__ros2_dot_humble_dot_moveit__msgs_dot_msg_dot_robot__state__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nEmake87_messages_ros2/humble/moveit_msgs/msg/position_ik_request.proto\x12+make87_messages_ros2.humble.moveit_msgs.msg\x1a!make87_messages/core/header.proto\x1a\x41make87_messages_ros2/humble/builtin_interfaces/msg/duration.proto\x1a@make87_messages_ros2/humble/geometry_msgs/msg/pose_stamped.proto\x1a=make87_messages_ros2/humble/moveit_msgs/msg/constraints.proto\x1a=make87_messages_ros2/humble/moveit_msgs/msg/robot_state.proto\"\xb3\x04\n\x11PositionIKRequest\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12\x12\n\ngroup_name\x18\x02 \x01(\t\x12L\n\x0brobot_state\x18\x03 \x01(\x0b\x32\x37.make87_messages_ros2.humble.moveit_msgs.msg.RobotState\x12M\n\x0b\x63onstraints\x18\x04 \x01(\x0b\x32\x38.make87_messages_ros2.humble.moveit_msgs.msg.Constraints\x12\x18\n\x10\x61void_collisions\x18\x05 \x01(\x08\x12\x14\n\x0cik_link_name\x18\x06 \x01(\t\x12P\n\x0cpose_stamped\x18\x07 \x01(\x0b\x32:.make87_messages_ros2.humble.geometry_msgs.msg.PoseStamped\x12\x15\n\rik_link_names\x18\x08 \x03(\t\x12W\n\x13pose_stamped_vector\x18\t \x03(\x0b\x32:.make87_messages_ros2.humble.geometry_msgs.msg.PoseStamped\x12M\n\x07timeout\x18\n \x01(\x0b\x32<.make87_messages_ros2.humble.builtin_interfaces.msg.Durationb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.humble.moveit_msgs.msg.position_ik_request_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_POSITIONIKREQUEST']._serialized_start=413
  _globals['_POSITIONIKREQUEST']._serialized_end=976
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/rosbridge_msgs/msg/connected_clients.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.rosbridge_msgs.msg import connected_client_pb2 as make87__messages__ros2_dot_jazzy_dot_rosbridge__msgs_dot_msg_dot_connected__client__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nEmake87_messages_ros2/jazzy/rosbridge_msgs/msg/connected_clients.proto\x12-make87_messages_ros2.jazzy.rosbridge_msgs.msg\x1a\x44make87_messages_ros2/jazzy/rosbridge_msgs/msg/connected_client.proto\"c\n\x10\x43onnectedClients\x12O\n\x07\x63lients\x18\x01 \x03(\x0b\x32>.make87_messages_ros2.jazzy.rosbridge_msgs.msg.ConnectedClientb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.rosbridge_msgs.msg.connected_clients_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_CONNECTEDCLIENTS']._serialized_start=190
  _globals['_CONNECTEDCLIENTS']._serialized_end=289
# @@protoc_insertion_point(module_scope)



from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class BodyRequestRequest(_message.Message):
    __slots__ = ["body_name"]
    BODY_NAME_FIELD_NUMBER: _ClassVar[int]
    body_name: str
    def __init__(self, body_name: _Optional[str] = ...) -> None: ...

class BodyRequestResponse(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...



from make87_messages_ros2.rolling.rmf_traffic_msgs.msg import convex_shape_pb2 as _convex_shape_pb2
from make87_messages_ros2.rolling.rmf_traffic_msgs.msg import convex_shape_context_pb2 as _convex_shape_context_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Profile(_message.Message):
    __slots__ = ["footprint", "vicinity", "shape_context"]
    FOOTPRINT_FIELD_NUMBER: _ClassVar[int]
    VICINITY_FIELD_NUMBER: _ClassVar[int]
    SHAPE_CONTEXT_FIELD_NUMBER: _ClassVar[int]
    footprint: _convex_shape_pb2.ConvexShape
    vicinity: _convex_shape_pb2.ConvexShape
    shape_context: _convex_shape_context_pb2.ConvexShapeContext
    def __init__(self, footprint: _Optional[_Union[_convex_shape_pb2.ConvexShape, _Mapping]] = ..., vicinity: _Optional[_Union[_convex_shape_pb2.ConvexShape, _Mapping]] = ..., shape_context: _Optional[_Union[_convex_shape_context_pb2.ConvexShapeContext, _Mapping]] = ...) -> None: ...



from make87_messages.core import header_pb2 as _header_pb2
from make87_messages_ros2.humble.std_msgs.msg import header_pb2 as _header_pb2_1
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class SingleBatteryInfo(_message.Message):
    __slots__ = ["header", "ros2_header", "battery_index", "voltage", "current", "full_capacity", "capacity_remain", "capacity_percentage", "temperature", "cell_count", "self_check_error", "closed_reason", "abnormal_comm", "is_embed"]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    ROS2_HEADER_FIELD_NUMBER: _ClassVar[int]
    BATTERY_INDEX_FIELD_NUMBER: _ClassVar[int]
    VOLTAGE_FIELD_NUMBER: _ClassVar[int]
    CURRENT_FIELD_NUMBER: _ClassVar[int]
    FULL_CAPACITY_FIELD_NUMBER: _ClassVar[int]
    CAPACITY_REMAIN_FIELD_NUMBER: _ClassVar[int]
    CAPACITY_PERCENTAGE_FIELD_NUMBER: _ClassVar[int]
    TEMPERATURE_FIELD_NUMBER: _ClassVar[int]
    CELL_COUNT_FIELD_NUMBER: _ClassVar[int]
    SELF_CHECK_ERROR_FIELD_NUMBER: _ClassVar[int]
    CLOSED_REASON_FIELD_NUMBER: _ClassVar[int]
    ABNORMAL_COMM_FIELD_NUMBER: _ClassVar[int]
    IS_EMBED_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    ros2_header: _header_pb2_1.Header
    battery_index: int
    voltage: float
    current: float
    full_capacity: float
    capacity_remain: float
    capacity_percentage: float
    temperature: float
    cell_count: int
    self_check_error: int
    closed_reason: int
    abnormal_comm: int
    is_embed: int
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., ros2_header: _Optional[_Union[_header_pb2_1.Header, _Mapping]] = ..., battery_index: _Optional[int] = ..., voltage: _Optional[float] = ..., current: _Optional[float] = ..., full_capacity: _Optional[float] = ..., capacity_remain: _Optional[float] = ..., capacity_percentage: _Optional[float] = ..., temperature: _Optional[float] = ..., cell_count: _Optional[int] = ..., self_check_error: _Optional[int] = ..., closed_reason: _Optional[int] = ..., abnormal_comm: _Optional[int] = ..., is_embed: _Optional[int] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/tuw_object_msgs/msg/object_with_covariance.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.rolling.tuw_object_msgs.msg import object_pb2 as make87__messages__ros2_dot_rolling_dot_tuw__object__msgs_dot_msg_dot_object__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nMmake87_messages_ros2/rolling/tuw_object_msgs/msg/object_with_covariance.proto\x12\x30make87_messages_ros2.rolling.tuw_object_msgs.msg\x1a=make87_messages_ros2/rolling/tuw_object_msgs/msg/object.proto\"\xa8\x01\n\x14ObjectWithCovariance\x12H\n\x06object\x18\x01 \x01(\x0b\x32\x38.make87_messages_ros2.rolling.tuw_object_msgs.msg.Object\x12\x17\n\x0f\x63ovariance_pose\x18\x02 \x03(\x01\x12\x18\n\x10\x63ovariance_twist\x18\x03 \x03(\x01\x12\x13\n\x0b\x63orrelation\x18\x04 \x03(\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.tuw_object_msgs.msg.object_with_covariance_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_OBJECTWITHCOVARIANCE']._serialized_start=195
  _globals['_OBJECTWITHCOVARIANCE']._serialized_end=363
# @@protoc_insertion_point(module_scope)



from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class SigFlags(_message.Message):
    __slots__ = ["health", "pr_smoothed", "pr_used", "cr_used", "do_used", "pr_corr_used", "cr_corr_used", "do_corr_used"]
    HEALTH_FIELD_NUMBER: _ClassVar[int]
    PR_SMOOTHED_FIELD_NUMBER: _ClassVar[int]
    PR_USED_FIELD_NUMBER: _ClassVar[int]
    CR_USED_FIELD_NUMBER: _ClassVar[int]
    DO_USED_FIELD_NUMBER: _ClassVar[int]
    PR_CORR_USED_FIELD_NUMBER: _ClassVar[int]
    CR_CORR_USED_FIELD_NUMBER: _ClassVar[int]
    DO_CORR_USED_FIELD_NUMBER: _ClassVar[int]
    health: int
    pr_smoothed: bool
    pr_used: bool
    cr_used: bool
    do_used: bool
    pr_corr_used: bool
    cr_corr_used: bool
    do_corr_used: bool
    def __init__(self, health: _Optional[int] = ..., pr_smoothed: bool = ..., pr_used: bool = ..., cr_used: bool = ..., do_used: bool = ..., pr_corr_used: bool = ..., cr_corr_used: bool = ..., do_corr_used: bool = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/mavros_msgs/msg/param_event.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.rcl_interfaces.msg import parameter_value_pb2 as make87__messages__ros2_dot_jazzy_dot_rcl__interfaces_dot_msg_dot_parameter__value__pb2
from make87_messages_ros2.jazzy.std_msgs.msg import header_pb2 as make87__messages__ros2_dot_jazzy_dot_std__msgs_dot_msg_dot_header__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n<make87_messages_ros2/jazzy/mavros_msgs/msg/param_event.proto\x12*make87_messages_ros2.jazzy.mavros_msgs.msg\x1a\x43make87_messages_ros2/jazzy/rcl_interfaces/msg/parameter_value.proto\x1a\x34make87_messages_ros2/jazzy/std_msgs/msg/header.proto\"\xd7\x01\n\nParamEvent\x12?\n\x06header\x18\x01 \x01(\x0b\x32/.make87_messages_ros2.jazzy.std_msgs.msg.Header\x12\x10\n\x08param_id\x18\x02 \x01(\t\x12L\n\x05value\x18\x03 \x01(\x0b\x32=.make87_messages_ros2.jazzy.rcl_interfaces.msg.ParameterValue\x12\x13\n\x0bparam_index\x18\x04 \x01(\r\x12\x13\n\x0bparam_count\x18\x05 \x01(\rb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.mavros_msgs.msg.param_event_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_PARAMEVENT']._serialized_start=232
  _globals['_PARAMEVENT']._serialized_end=447
# @@protoc_insertion_point(module_scope)



from make87_messages_ros2.jazzy.rcl_interfaces.msg import parameter_value_pb2 as _parameter_value_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Parameter(_message.Message):
    __slots__ = ["name", "value"]
    NAME_FIELD_NUMBER: _ClassVar[int]
    VALUE_FIELD_NUMBER: _ClassVar[int]
    name: str
    value: _parameter_value_pb2.ParameterValue
    def __init__(self, name: _Optional[str] = ..., value: _Optional[_Union[_parameter_value_pb2.ParameterValue, _Mapping]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/rc_reason_msgs/srv/warmup_template.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.rolling.rc_common_msgs.msg import return_code_pb2 as make87__messages__ros2_dot_rolling_dot_rc__common__msgs_dot_msg_dot_return__code__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nEmake87_messages_ros2/rolling/rc_reason_msgs/srv/warmup_template.proto\x12/make87_messages_ros2.rolling.rc_reason_msgs.srv\x1a\x41make87_messages_ros2/rolling/rc_common_msgs/msg/return_code.proto\",\n\x15WarmupTemplateRequest\x12\x13\n\x0btemplate_id\x18\x01 \x01(\t\"j\n\x16WarmupTemplateResponse\x12P\n\x0breturn_code\x18\x01 \x01(\x0b\x32;.make87_messages_ros2.rolling.rc_common_msgs.msg.ReturnCodeb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.rc_reason_msgs.srv.warmup_template_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_WARMUPTEMPLATEREQUEST']._serialized_start=189
  _globals['_WARMUPTEMPLATEREQUEST']._serialized_end=233
  _globals['_WARMUPTEMPLATERESPONSE']._serialized_start=235
  _globals['_WARMUPTEMPLATERESPONSE']._serialized_end=341
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/automotive_navigation_msgs/msg/point_of_interest_response.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.automotive_navigation_msgs.msg import point_of_interest_status_pb2 as make87__messages__ros2_dot_jazzy_dot_automotive__navigation__msgs_dot_msg_dot_point__of__interest__status__pb2
from make87_messages_ros2.jazzy.std_msgs.msg import header_pb2 as make87__messages__ros2_dot_jazzy_dot_std__msgs_dot_msg_dot_header__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nZmake87_messages_ros2/jazzy/automotive_navigation_msgs/msg/point_of_interest_response.proto\x12\x39make87_messages_ros2.jazzy.automotive_navigation_msgs.msg\x1aXmake87_messages_ros2/jazzy/automotive_navigation_msgs/msg/point_of_interest_status.proto\x1a\x34make87_messages_ros2/jazzy/std_msgs/msg/header.proto\"\x8f\x02\n\x17PointOfInterestResponse\x12?\n\x06header\x18\x01 \x01(\x0b\x32/.make87_messages_ros2.jazzy.std_msgs.msg.Header\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x13\n\x0bmodule_name\x18\x03 \x01(\t\x12\x12\n\nrequest_id\x18\x04 \x01(\r\x12\x12\n\nupdate_num\x18\x05 \x01(\r\x12h\n\x0epoint_statuses\x18\x06 \x03(\x0b\x32P.make87_messages_ros2.jazzy.automotive_navigation_msgs.msg.PointOfInterestStatusb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.automotive_navigation_msgs.msg.point_of_interest_response_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_POINTOFINTERESTRESPONSE']._serialized_start=298
  _globals['_POINTOFINTERESTRESPONSE']._serialized_end=569
# @@protoc_insertion_point(module_scope)



from make87_messages.core import header_pb2 as _header_pb2
from make87_messages_ros2.humble.geographic_msgs.msg import geo_path_pb2 as _geo_path_pb2
from make87_messages_ros2.humble.nav_msgs.msg import path_pb2 as _path_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class PathToGeopathRequest(_message.Message):
    __slots__ = ["header", "path"]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    PATH_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    path: _path_pb2.Path
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., path: _Optional[_Union[_path_pb2.Path, _Mapping]] = ...) -> None: ...

class PathToGeopathResponse(_message.Message):
    __slots__ = ["header", "success", "geo_path"]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    SUCCESS_FIELD_NUMBER: _ClassVar[int]
    GEO_PATH_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    success: bool
    geo_path: _geo_path_pb2.GeoPath
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., success: bool = ..., geo_path: _Optional[_Union[_geo_path_pb2.GeoPath, _Mapping]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/controller_manager_msgs/srv/reload_controller_libraries.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nZmake87_messages_ros2/rolling/controller_manager_msgs/srv/reload_controller_libraries.proto\x12\x38make87_messages_ros2.rolling.controller_manager_msgs.srv\"6\n ReloadControllerLibrariesRequest\x12\x12\n\nforce_kill\x18\x01 \x01(\x08\"/\n!ReloadControllerLibrariesResponse\x12\n\n\x02ok\x18\x01 \x01(\x08\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.controller_manager_msgs.srv.reload_controller_libraries_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_RELOADCONTROLLERLIBRARIESREQUEST']._serialized_start=152
  _globals['_RELOADCONTROLLERLIBRARIESREQUEST']._serialized_end=206
  _globals['_RELOADCONTROLLERLIBRARIESRESPONSE']._serialized_start=208
  _globals['_RELOADCONTROLLERLIBRARIESRESPONSE']._serialized_end=255
# @@protoc_insertion_point(module_scope)



from make87_messages.core import header_pb2 as _header_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class FileRenameRequest(_message.Message):
    __slots__ = ["header", "old_path", "new_path"]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    OLD_PATH_FIELD_NUMBER: _ClassVar[int]
    NEW_PATH_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    old_path: str
    new_path: str
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., old_path: _Optional[str] = ..., new_path: _Optional[str] = ...) -> None: ...

class FileRenameResponse(_message.Message):
    __slots__ = ["header", "success", "r_errno"]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    SUCCESS_FIELD_NUMBER: _ClassVar[int]
    R_ERRNO_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    success: bool
    r_errno: int
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., success: bool = ..., r_errno: _Optional[int] = ...) -> None: ...



from make87_messages_ros2.jazzy.test_interface_files.msg import basic_types_pb2 as _basic_types_pb2
from make87_messages_ros2.jazzy.test_interface_files.msg import constants_pb2 as _constants_pb2
from make87_messages_ros2.jazzy.test_interface_files.msg import defaults_pb2 as _defaults_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class BoundedSequences(_message.Message):
    __slots__ = ["bool_values", "byte_values", "char_values", "float32_values", "float64_values", "int8_values", "uint8_values", "int16_values", "uint16_values", "int32_values", "uint32_values", "int64_values", "uint64_values", "string_values", "basic_types_values", "constants_values", "defaults_values", "bool_values_default", "byte_values_default", "char_values_default", "float32_values_default", "float64_values_default", "int8_values_default", "uint8_values_default", "int16_values_default", "uint16_values_default", "int32_values_default", "uint32_values_default", "int64_values_default", "uint64_values_default", "string_values_default", "alignment_check"]
    BOOL_VALUES_FIELD_NUMBER: _ClassVar[int]
    BYTE_VALUES_FIELD_NUMBER: _ClassVar[int]
    CHAR_VALUES_FIELD_NUMBER: _ClassVar[int]
    FLOAT32_VALUES_FIELD_NUMBER: _ClassVar[int]
    FLOAT64_VALUES_FIELD_NUMBER: _ClassVar[int]
    INT8_VALUES_FIELD_NUMBER: _ClassVar[int]
    UINT8_VALUES_FIELD_NUMBER: _ClassVar[int]
    INT16_VALUES_FIELD_NUMBER: _ClassVar[int]
    UINT16_VALUES_FIELD_NUMBER: _ClassVar[int]
    INT32_VALUES_FIELD_NUMBER: _ClassVar[int]
    UINT32_VALUES_FIELD_NUMBER: _ClassVar[int]
    INT64_VALUES_FIELD_NUMBER: _ClassVar[int]
    UINT64_VALUES_FIELD_NUMBER: _ClassVar[int]
    STRING_VALUES_FIELD_NUMBER: _ClassVar[int]
    BASIC_TYPES_VALUES_FIELD_NUMBER: _ClassVar[int]
    CONSTANTS_VALUES_FIELD_NUMBER: _ClassVar[int]
    DEFAULTS_VALUES_FIELD_NUMBER: _ClassVar[int]
    BOOL_VALUES_DEFAULT_FIELD_NUMBER: _ClassVar[int]
    BYTE_VALUES_DEFAULT_FIELD_NUMBER: _ClassVar[int]
    CHAR_VALUES_DEFAULT_FIELD_NUMBER: _ClassVar[int]
    FLOAT32_VALUES_DEFAULT_FIELD_NUMBER: _ClassVar[int]
    FLOAT64_VALUES_DEFAULT_FIELD_NUMBER: _ClassVar[int]
    INT8_VALUES_DEFAULT_FIELD_NUMBER: _ClassVar[int]
    UINT8_VALUES_DEFAULT_FIELD_NUMBER: _ClassVar[int]
    INT16_VALUES_DEFAULT_FIELD_NUMBER: _ClassVar[int]
    UINT16_VALUES_DEFAULT_FIELD_NUMBER: _ClassVar[int]
    INT32_VALUES_DEFAULT_FIELD_NUMBER: _ClassVar[int]
    UINT32_VALUES_DEFAULT_FIELD_NUMBER: _ClassVar[int]
    INT64_VALUES_DEFAULT_FIELD_NUMBER: _ClassVar[int]
    UINT64_VALUES_DEFAULT_FIELD_NUMBER: _ClassVar[int]
    STRING_VALUES_DEFAULT_FIELD_NUMBER: _ClassVar[int]
    ALIGNMENT_CHECK_FIELD_NUMBER: _ClassVar[int]
    bool_values: _containers.RepeatedScalarFieldContainer[bool]
    byte_values: _containers.RepeatedScalarFieldContainer[int]
    char_values: _containers.RepeatedScalarFieldContainer[int]
    float32_values: _containers.RepeatedScalarFieldContainer[float]
    float64_values: _containers.RepeatedScalarFieldContainer[float]
    int8_values: _containers.RepeatedScalarFieldContainer[int]
    uint8_values: _containers.RepeatedScalarFieldContainer[int]
    int16_values: _containers.RepeatedScalarFieldContainer[int]
    uint16_values: _containers.RepeatedScalarFieldContainer[int]
    int32_values: _containers.RepeatedScalarFieldContainer[int]
    uint32_values: _containers.RepeatedScalarFieldContainer[int]
    int64_values: _containers.RepeatedScalarFieldContainer[int]
    uint64_values: _containers.RepeatedScalarFieldContainer[int]
    string_values: _containers.RepeatedScalarFieldContainer[str]
    basic_types_values: _containers.RepeatedCompositeFieldContainer[_basic_types_pb2.BasicTypes]
    constants_values: _containers.RepeatedCompositeFieldContainer[_constants_pb2.Constants]
    defaults_values: _containers.RepeatedCompositeFieldContainer[_defaults_pb2.Defaults]
    bool_values_default: _containers.RepeatedScalarFieldContainer[bool]
    byte_values_default: _containers.RepeatedScalarFieldContainer[int]
    char_values_default: _containers.RepeatedScalarFieldContainer[int]
    float32_values_default: _containers.RepeatedScalarFieldContainer[float]
    float64_values_default: _containers.RepeatedScalarFieldContainer[float]
    int8_values_default: _containers.RepeatedScalarFieldContainer[int]
    uint8_values_default: _containers.RepeatedScalarFieldContainer[int]
    int16_values_default: _containers.RepeatedScalarFieldContainer[int]
    uint16_values_default: _containers.RepeatedScalarFieldContainer[int]
    int32_values_default: _containers.RepeatedScalarFieldContainer[int]
    uint32_values_default: _containers.RepeatedScalarFieldContainer[int]
    int64_values_default: _containers.RepeatedScalarFieldContainer[int]
    uint64_values_default: _containers.RepeatedScalarFieldContainer[int]
    string_values_default: _containers.RepeatedScalarFieldContainer[str]
    alignment_check: int
    def __init__(self, bool_values: _Optional[_Iterable[bool]] = ..., byte_values: _Optional[_Iterable[int]] = ..., char_values: _Optional[_Iterable[int]] = ..., float32_values: _Optional[_Iterable[float]] = ..., float64_values: _Optional[_Iterable[float]] = ..., int8_values: _Optional[_Iterable[int]] = ..., uint8_values: _Optional[_Iterable[int]] = ..., int16_values: _Optional[_Iterable[int]] = ..., uint16_values: _Optional[_Iterable[int]] = ..., int32_values: _Optional[_Iterable[int]] = ..., uint32_values: _Optional[_Iterable[int]] = ..., int64_values: _Optional[_Iterable[int]] = ..., uint64_values: _Optional[_Iterable[int]] = ..., string_values: _Optional[_Iterable[str]] = ..., basic_types_values: _Optional[_Iterable[_Union[_basic_types_pb2.BasicTypes, _Mapping]]] = ..., constants_values: _Optional[_Iterable[_Union[_constants_pb2.Constants, _Mapping]]] = ..., defaults_values: _Optional[_Iterable[_Union[_defaults_pb2.Defaults, _Mapping]]] = ..., bool_values_default: _Optional[_Iterable[bool]] = ..., byte_values_default: _Optional[_Iterable[int]] = ..., char_values_default: _Optional[_Iterable[int]] = ..., float32_values_default: _Optional[_Iterable[float]] = ..., float64_values_default: _Optional[_Iterable[float]] = ..., int8_values_default: _Optional[_Iterable[int]] = ..., uint8_values_default: _Optional[_Iterable[int]] = ..., int16_values_default: _Optional[_Iterable[int]] = ..., uint16_values_default: _Optional[_Iterable[int]] = ..., int32_values_default: _Optional[_Iterable[int]] = ..., uint32_values_default: _Optional[_Iterable[int]] = ..., int64_values_default: _Optional[_Iterable[int]] = ..., uint64_values_default: _Optional[_Iterable[int]] = ..., string_values_default: _Optional[_Iterable[str]] = ..., alignment_check: _Optional[int] = ...) -> None: ...



from make87_messages.core import header_pb2 as _header_pb2
from make87_messages_ros2.humble.moveit_msgs.msg import joint_constraint_pb2 as _joint_constraint_pb2
from make87_messages_ros2.humble.moveit_msgs.msg import orientation_constraint_pb2 as _orientation_constraint_pb2
from make87_messages_ros2.humble.moveit_msgs.msg import position_constraint_pb2 as _position_constraint_pb2
from make87_messages_ros2.humble.moveit_msgs.msg import visibility_constraint_pb2 as _visibility_constraint_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Constraints(_message.Message):
    __slots__ = ["header", "name", "joint_constraints", "position_constraints", "orientation_constraints", "visibility_constraints"]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    JOINT_CONSTRAINTS_FIELD_NUMBER: _ClassVar[int]
    POSITION_CONSTRAINTS_FIELD_NUMBER: _ClassVar[int]
    ORIENTATION_CONSTRAINTS_FIELD_NUMBER: _ClassVar[int]
    VISIBILITY_CONSTRAINTS_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    name: str
    joint_constraints: _containers.RepeatedCompositeFieldContainer[_joint_constraint_pb2.JointConstraint]
    position_constraints: _containers.RepeatedCompositeFieldContainer[_position_constraint_pb2.PositionConstraint]
    orientation_constraints: _containers.RepeatedCompositeFieldContainer[_orientation_constraint_pb2.OrientationConstraint]
    visibility_constraints: _containers.RepeatedCompositeFieldContainer[_visibility_constraint_pb2.VisibilityConstraint]
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., name: _Optional[str] = ..., joint_constraints: _Optional[_Iterable[_Union[_joint_constraint_pb2.JointConstraint, _Mapping]]] = ..., position_constraints: _Optional[_Iterable[_Union[_position_constraint_pb2.PositionConstraint, _Mapping]]] = ..., orientation_constraints: _Optional[_Iterable[_Union[_orientation_constraint_pb2.OrientationConstraint, _Mapping]]] = ..., visibility_constraints: _Optional[_Iterable[_Union[_visibility_constraint_pb2.VisibilityConstraint, _Mapping]]] = ...) -> None: ...



from make87_messages.core import header_pb2 as _header_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class SbgStatusAiding(_message.Message):
    __slots__ = ["header", "gps1_pos_recv", "gps1_vel_recv", "gps1_hdt_recv", "gps1_utc_recv", "gps2_pos_recv", "gps2_vel_recv", "gps2_hdt_recv", "gps2_utc_recv", "mag_recv", "odo_recv", "dvl_recv", "usbl_recv", "depth_recv", "air_data_recv", "user_pos_recv", "user_vel_recv", "user_heading_recv"]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    GPS1_POS_RECV_FIELD_NUMBER: _ClassVar[int]
    GPS1_VEL_RECV_FIELD_NUMBER: _ClassVar[int]
    GPS1_HDT_RECV_FIELD_NUMBER: _ClassVar[int]
    GPS1_UTC_RECV_FIELD_NUMBER: _ClassVar[int]
    GPS2_POS_RECV_FIELD_NUMBER: _ClassVar[int]
    GPS2_VEL_RECV_FIELD_NUMBER: _ClassVar[int]
    GPS2_HDT_RECV_FIELD_NUMBER: _ClassVar[int]
    GPS2_UTC_RECV_FIELD_NUMBER: _ClassVar[int]
    MAG_RECV_FIELD_NUMBER: _ClassVar[int]
    ODO_RECV_FIELD_NUMBER: _ClassVar[int]
    DVL_RECV_FIELD_NUMBER: _ClassVar[int]
    USBL_RECV_FIELD_NUMBER: _ClassVar[int]
    DEPTH_RECV_FIELD_NUMBER: _ClassVar[int]
    AIR_DATA_RECV_FIELD_NUMBER: _ClassVar[int]
    USER_POS_RECV_FIELD_NUMBER: _ClassVar[int]
    USER_VEL_RECV_FIELD_NUMBER: _ClassVar[int]
    USER_HEADING_RECV_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    gps1_pos_recv: bool
    gps1_vel_recv: bool
    gps1_hdt_recv: bool
    gps1_utc_recv: bool
    gps2_pos_recv: bool
    gps2_vel_recv: bool
    gps2_hdt_recv: bool
    gps2_utc_recv: bool
    mag_recv: bool
    odo_recv: bool
    dvl_recv: bool
    usbl_recv: bool
    depth_recv: bool
    air_data_recv: bool
    user_pos_recv: bool
    user_vel_recv: bool
    user_heading_recv: bool
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., gps1_pos_recv: bool = ..., gps1_vel_recv: bool = ..., gps1_hdt_recv: bool = ..., gps1_utc_recv: bool = ..., gps2_pos_recv: bool = ..., gps2_vel_recv: bool = ..., gps2_hdt_recv: bool = ..., gps2_utc_recv: bool = ..., mag_recv: bool = ..., odo_recv: bool = ..., dvl_recv: bool = ..., usbl_recv: bool = ..., depth_recv: bool = ..., air_data_recv: bool = ..., user_pos_recv: bool = ..., user_vel_recv: bool = ..., user_heading_recv: bool = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/mavros_msgs/msg/waypoint_reached.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.std_msgs.msg import header_pb2 as make87__messages__ros2_dot_jazzy_dot_std__msgs_dot_msg_dot_header__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nAmake87_messages_ros2/jazzy/mavros_msgs/msg/waypoint_reached.proto\x12*make87_messages_ros2.jazzy.mavros_msgs.msg\x1a\x34make87_messages_ros2/jazzy/std_msgs/msg/header.proto\"b\n\x0fWaypointReached\x12?\n\x06header\x18\x01 \x01(\x0b\x32/.make87_messages_ros2.jazzy.std_msgs.msg.Header\x12\x0e\n\x06wp_seq\x18\x02 \x01(\rb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.mavros_msgs.msg.waypoint_reached_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_WAYPOINTREACHED']._serialized_start=167
  _globals['_WAYPOINTREACHED']._serialized_end=265
# @@protoc_insertion_point(module_scope)



from make87_messages_ros2.rolling.rmf_traffic_msgs.msg import participant_description_pb2 as _participant_description_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Participant(_message.Message):
    __slots__ = ["id", "description"]
    ID_FIELD_NUMBER: _ClassVar[int]
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    id: int
    description: _participant_description_pb2.ParticipantDescription
    def __init__(self, id: _Optional[int] = ..., description: _Optional[_Union[_participant_description_pb2.ParticipantDescription, _Mapping]] = ...) -> None: ...



from make87_messages.core import header_pb2 as _header_pb2
from make87_messages_ros2.humble.nav_msgs.msg import occupancy_grid_pb2 as _occupancy_grid_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class LoadMapRequest(_message.Message):
    __slots__ = ["header", "map_url"]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    MAP_URL_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    map_url: str
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., map_url: _Optional[str] = ...) -> None: ...

class LoadMapResponse(_message.Message):
    __slots__ = ["header", "map", "result"]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    MAP_FIELD_NUMBER: _ClassVar[int]
    RESULT_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    map: _occupancy_grid_pb2.OccupancyGrid
    result: int
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., map: _Optional[_Union[_occupancy_grid_pb2.OccupancyGrid, _Mapping]] = ..., result: _Optional[int] = ...) -> None: ...



from make87_messages.core import header_pb2 as _header_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class IOOSSDSState(_message.Message):
    __slots__ = ["header", "ossd1a", "ossd1b", "ossd2a", "ossd2b"]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    OSSD1A_FIELD_NUMBER: _ClassVar[int]
    OSSD1B_FIELD_NUMBER: _ClassVar[int]
    OSSD2A_FIELD_NUMBER: _ClassVar[int]
    OSSD2B_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    ossd1a: int
    ossd1b: int
    ossd2a: int
    ossd2b: int
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., ossd1a: _Optional[int] = ..., ossd1b: _Optional[int] = ..., ossd2a: _Optional[int] = ..., ossd2b: _Optional[int] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/ublox_ubx_msgs/msg/ubx_rxm_measx.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.std_msgs.msg import header_pb2 as make87__messages__ros2_dot_jazzy_dot_std__msgs_dot_msg_dot_header__pb2
from make87_messages_ros2.jazzy.ublox_ubx_msgs.msg import measx_data_pb2 as make87__messages__ros2_dot_jazzy_dot_ublox__ubx__msgs_dot_msg_dot_measx__data__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nAmake87_messages_ros2/jazzy/ublox_ubx_msgs/msg/ubx_rxm_measx.proto\x12-make87_messages_ros2.jazzy.ublox_ubx_msgs.msg\x1a\x34make87_messages_ros2/jazzy/std_msgs/msg/header.proto\x1a>make87_messages_ros2/jazzy/ublox_ubx_msgs/msg/measx_data.proto\"\xe3\x02\n\x0bUBXRxmMeasx\x12?\n\x06header\x18\x01 \x01(\x0b\x32/.make87_messages_ros2.jazzy.std_msgs.msg.Header\x12\x0f\n\x07version\x18\x02 \x01(\r\x12\x0f\n\x07gps_tow\x18\x03 \x01(\r\x12\x0f\n\x07glo_tow\x18\x04 \x01(\r\x12\x0f\n\x07\x62\x64s_tow\x18\x05 \x01(\r\x12\x10\n\x08qzss_tow\x18\x06 \x01(\r\x12\x13\n\x0bgps_tow_acc\x18\x07 \x01(\r\x12\x13\n\x0bglo_tow_acc\x18\x08 \x01(\r\x12\x13\n\x0b\x62\x64s_tow_acc\x18\t \x01(\r\x12\x14\n\x0cqzss_tow_acc\x18\n \x01(\r\x12\x0e\n\x06num_sv\x18\x0b \x01(\r\x12\r\n\x05\x66lags\x18\x0c \x01(\r\x12I\n\x07sv_data\x18\r \x03(\x0b\x32\x38.make87_messages_ros2.jazzy.ublox_ubx_msgs.msg.MeasxDatab\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.ublox_ubx_msgs.msg.ubx_rxm_measx_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_UBXRXMMEASX']._serialized_start=235
  _globals['_UBXRXMMEASX']._serialized_end=590
# @@protoc_insertion_point(module_scope)



from make87_messages_ros2.jazzy.autoware_map_msgs.msg import lanelet_map_bin_pb2 as _lanelet_map_bin_pb2
from make87_messages_ros2.jazzy.std_msgs.msg import header_pb2 as _header_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class GetSelectedLanelet2MapRequest(_message.Message):
    __slots__ = ["cell_ids"]
    CELL_IDS_FIELD_NUMBER: _ClassVar[int]
    cell_ids: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, cell_ids: _Optional[_Iterable[str]] = ...) -> None: ...

class GetSelectedLanelet2MapResponse(_message.Message):
    __slots__ = ["header", "lanelet2_cells"]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    LANELET2_CELLS_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    lanelet2_cells: _lanelet_map_bin_pb2.LaneletMapBin
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., lanelet2_cells: _Optional[_Union[_lanelet_map_bin_pb2.LaneletMapBin, _Mapping]] = ...) -> None: ...



from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class RouterStatus(_message.Message):
    __slots__ = ["id", "success", "missing_robots", "duration", "overall_path_length", "longest_path_length", "priority_scheduling_attemps", "speed_scheduling_attemps"]
    ID_FIELD_NUMBER: _ClassVar[int]
    SUCCESS_FIELD_NUMBER: _ClassVar[int]
    MISSING_ROBOTS_FIELD_NUMBER: _ClassVar[int]
    DURATION_FIELD_NUMBER: _ClassVar[int]
    OVERALL_PATH_LENGTH_FIELD_NUMBER: _ClassVar[int]
    LONGEST_PATH_LENGTH_FIELD_NUMBER: _ClassVar[int]
    PRIORITY_SCHEDULING_ATTEMPS_FIELD_NUMBER: _ClassVar[int]
    SPEED_SCHEDULING_ATTEMPS_FIELD_NUMBER: _ClassVar[int]
    id: int
    success: bool
    missing_robots: _containers.RepeatedScalarFieldContainer[str]
    duration: int
    overall_path_length: int
    longest_path_length: int
    priority_scheduling_attemps: int
    speed_scheduling_attemps: int
    def __init__(self, id: _Optional[int] = ..., success: bool = ..., missing_robots: _Optional[_Iterable[str]] = ..., duration: _Optional[int] = ..., overall_path_length: _Optional[int] = ..., longest_path_length: _Optional[int] = ..., priority_scheduling_attemps: _Optional[int] = ..., speed_scheduling_attemps: _Optional[int] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/cartographer_ros_msgs/msg/submap_texture.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.rolling.geometry_msgs.msg import pose_pb2 as make87__messages__ros2_dot_rolling_dot_geometry__msgs_dot_msg_dot_pose__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nKmake87_messages_ros2/rolling/cartographer_ros_msgs/msg/submap_texture.proto\x12\x36make87_messages_ros2.rolling.cartographer_ros_msgs.msg\x1a\x39make87_messages_ros2/rolling/geometry_msgs/msg/pose.proto\"\x9b\x01\n\rSubmapTexture\x12\r\n\x05\x63\x65lls\x18\x01 \x03(\r\x12\r\n\x05width\x18\x02 \x01(\x05\x12\x0e\n\x06height\x18\x03 \x01(\x05\x12\x12\n\nresolution\x18\x04 \x01(\x01\x12H\n\nslice_pose\x18\x05 \x01(\x0b\x32\x34.make87_messages_ros2.rolling.geometry_msgs.msg.Poseb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.cartographer_ros_msgs.msg.submap_texture_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_SUBMAPTEXTURE']._serialized_start=195
  _globals['_SUBMAPTEXTURE']._serialized_end=350
# @@protoc_insertion_point(module_scope)



from make87_messages.core import header_pb2 as _header_pb2
from make87_messages_ros2.humble.geometry_msgs.msg import quaternion_pb2 as _quaternion_pb2
from make87_messages_ros2.humble.geometry_msgs.msg import vector3_pb2 as _vector3_pb2
from make87_messages_ros2.humble.std_msgs.msg import header_pb2 as _header_pb2_1
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Imu(_message.Message):
    __slots__ = ["header", "ros2_header", "orientation", "orientation_covariance", "angular_velocity", "angular_velocity_covariance", "linear_acceleration", "linear_acceleration_covariance"]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    ROS2_HEADER_FIELD_NUMBER: _ClassVar[int]
    ORIENTATION_FIELD_NUMBER: _ClassVar[int]
    ORIENTATION_COVARIANCE_FIELD_NUMBER: _ClassVar[int]
    ANGULAR_VELOCITY_FIELD_NUMBER: _ClassVar[int]
    ANGULAR_VELOCITY_COVARIANCE_FIELD_NUMBER: _ClassVar[int]
    LINEAR_ACCELERATION_FIELD_NUMBER: _ClassVar[int]
    LINEAR_ACCELERATION_COVARIANCE_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    ros2_header: _header_pb2_1.Header
    orientation: _quaternion_pb2.Quaternion
    orientation_covariance: _containers.RepeatedScalarFieldContainer[float]
    angular_velocity: _vector3_pb2.Vector3
    angular_velocity_covariance: _containers.RepeatedScalarFieldContainer[float]
    linear_acceleration: _vector3_pb2.Vector3
    linear_acceleration_covariance: _containers.RepeatedScalarFieldContainer[float]
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., ros2_header: _Optional[_Union[_header_pb2_1.Header, _Mapping]] = ..., orientation: _Optional[_Union[_quaternion_pb2.Quaternion, _Mapping]] = ..., orientation_covariance: _Optional[_Iterable[float]] = ..., angular_velocity: _Optional[_Union[_vector3_pb2.Vector3, _Mapping]] = ..., angular_velocity_covariance: _Optional[_Iterable[float]] = ..., linear_acceleration: _Optional[_Union[_vector3_pb2.Vector3, _Mapping]] = ..., linear_acceleration_covariance: _Optional[_Iterable[float]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/mqtt_client_interfaces/srv/new_ros2_mqtt_bridge.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nRmake87_messages_ros2/rolling/mqtt_client_interfaces/srv/new_ros2_mqtt_bridge.proto\x12\x37make87_messages_ros2.rolling.mqtt_client_interfaces.srv\"\xaf\x01\n\x18NewRos2MqttBridgeRequest\x12\x11\n\tros_topic\x18\x01 \x01(\t\x12\x12\n\nmqtt_topic\x18\x02 \x01(\t\x12\x11\n\tprimitive\x18\x03 \x01(\x08\x12\x18\n\x10inject_timestamp\x18\x04 \x01(\x08\x12\x16\n\x0eros_queue_size\x18\x05 \x01(\r\x12\x10\n\x08mqtt_qos\x18\x06 \x01(\r\x12\x15\n\rmqtt_retained\x18\x07 \x01(\x08\",\n\x19NewRos2MqttBridgeResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.mqtt_client_interfaces.srv.new_ros2_mqtt_bridge_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_NEWROS2MQTTBRIDGEREQUEST']._serialized_start=144
  _globals['_NEWROS2MQTTBRIDGEREQUEST']._serialized_end=319
  _globals['_NEWROS2MQTTBRIDGERESPONSE']._serialized_start=321
  _globals['_NEWROS2MQTTBRIDGERESPONSE']._serialized_end=365
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/ublox_ubx_msgs/msg/comms_port_info.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nEmake87_messages_ros2/rolling/ublox_ubx_msgs/msg/comms_port_info.proto\x12/make87_messages_ros2.rolling.ublox_ubx_msgs.msg\"\xf3\x01\n\rCommsPortInfo\x12\x0f\n\x07port_id\x18\x01 \x01(\r\x12\x12\n\ntx_pending\x18\x02 \x01(\r\x12\x10\n\x08tx_bytes\x18\x03 \x01(\r\x12\x10\n\x08tx_usage\x18\x04 \x01(\r\x12\x15\n\rtx_peak_usage\x18\x05 \x01(\r\x12\x12\n\nrx_pending\x18\x06 \x01(\r\x12\x10\n\x08rx_bytes\x18\x07 \x01(\r\x12\x10\n\x08rx_usage\x18\x08 \x01(\r\x12\x15\n\rrx_peak_usage\x18\t \x01(\r\x12\x14\n\x0coverrun_errs\x18\n \x01(\r\x12\x0c\n\x04msgs\x18\x0b \x03(\r\x12\x0f\n\x07skipped\x18\x0c \x01(\rb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.ublox_ubx_msgs.msg.comms_port_info_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_COMMSPORTINFO']._serialized_start=123
  _globals['_COMMSPORTINFO']._serialized_end=366
# @@protoc_insertion_point(module_scope)



from make87_messages.core import header_pb2 as _header_pb2
from make87_messages_ros2.humble.as2_msgs.msg import control_mode_pb2 as _control_mode_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class SetControlModeRequest(_message.Message):
    __slots__ = ["header", "control_mode"]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    CONTROL_MODE_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    control_mode: _control_mode_pb2.ControlMode
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., control_mode: _Optional[_Union[_control_mode_pb2.ControlMode, _Mapping]] = ...) -> None: ...

class SetControlModeResponse(_message.Message):
    __slots__ = ["header", "success"]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    SUCCESS_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    success: bool
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., success: bool = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/humble/ibeo_msgs/msg/scan_point2208.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages.core import header_pb2 as make87__messages_dot_core_dot_header__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n>make87_messages_ros2/humble/ibeo_msgs/msg/scan_point2208.proto\x12)make87_messages_ros2.humble.ibeo_msgs.msg\x1a!make87_messages/core/header.proto\"\xfd\x01\n\rScanPoint2208\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12\x0c\n\x04\x65\x63ho\x18\x02 \x01(\r\x12\r\n\x05layer\x18\x03 \x01(\r\x12\x19\n\x11transparent_point\x18\x04 \x01(\x08\x12\x1b\n\x13\x63lutter_atmospheric\x18\x05 \x01(\x08\x12\x0e\n\x06ground\x18\x06 \x01(\x08\x12\x0c\n\x04\x64irt\x18\x07 \x01(\x08\x12\x18\n\x10horizontal_angle\x18\x08 \x01(\x05\x12\x17\n\x0fradial_distance\x18\t \x01(\r\x12\x18\n\x10\x65\x63ho_pulse_width\x18\n \x01(\rb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.humble.ibeo_msgs.msg.scan_point2208_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_SCANPOINT2208']._serialized_start=145
  _globals['_SCANPOINT2208']._serialized_end=398
# @@protoc_insertion_point(module_scope)



from make87_messages_ros2.jazzy.std_msgs.msg import header_pb2 as _header_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class EsrStatus1(_message.Message):
    __slots__ = ["header", "canmsg", "rolling_count_1", "dsp_timestamp", "comm_error", "radius_curvature_calc", "scan_index", "yaw_rate_calc", "vehicle_speed_calc"]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    CANMSG_FIELD_NUMBER: _ClassVar[int]
    ROLLING_COUNT_1_FIELD_NUMBER: _ClassVar[int]
    DSP_TIMESTAMP_FIELD_NUMBER: _ClassVar[int]
    COMM_ERROR_FIELD_NUMBER: _ClassVar[int]
    RADIUS_CURVATURE_CALC_FIELD_NUMBER: _ClassVar[int]
    SCAN_INDEX_FIELD_NUMBER: _ClassVar[int]
    YAW_RATE_CALC_FIELD_NUMBER: _ClassVar[int]
    VEHICLE_SPEED_CALC_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    canmsg: str
    rolling_count_1: int
    dsp_timestamp: int
    comm_error: bool
    radius_curvature_calc: int
    scan_index: int
    yaw_rate_calc: float
    vehicle_speed_calc: float
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., canmsg: _Optional[str] = ..., rolling_count_1: _Optional[int] = ..., dsp_timestamp: _Optional[int] = ..., comm_error: bool = ..., radius_curvature_calc: _Optional[int] = ..., scan_index: _Optional[int] = ..., yaw_rate_calc: _Optional[float] = ..., vehicle_speed_calc: _Optional[float] = ...) -> None: ...



from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class CfgNAV5(_message.Message):
    __slots__ = ["mask", "dyn_model", "fix_mode", "fixed_alt", "fixed_alt_var", "min_elev", "dr_limit", "p_dop", "t_dop", "p_acc", "t_acc", "static_hold_thresh", "dgnss_time_out", "cno_thresh_num_svs", "cno_thresh", "reserved1", "static_hold_max_dist", "utc_standard", "reserved2"]
    MASK_FIELD_NUMBER: _ClassVar[int]
    DYN_MODEL_FIELD_NUMBER: _ClassVar[int]
    FIX_MODE_FIELD_NUMBER: _ClassVar[int]
    FIXED_ALT_FIELD_NUMBER: _ClassVar[int]
    FIXED_ALT_VAR_FIELD_NUMBER: _ClassVar[int]
    MIN_ELEV_FIELD_NUMBER: _ClassVar[int]
    DR_LIMIT_FIELD_NUMBER: _ClassVar[int]
    P_DOP_FIELD_NUMBER: _ClassVar[int]
    T_DOP_FIELD_NUMBER: _ClassVar[int]
    P_ACC_FIELD_NUMBER: _ClassVar[int]
    T_ACC_FIELD_NUMBER: _ClassVar[int]
    STATIC_HOLD_THRESH_FIELD_NUMBER: _ClassVar[int]
    DGNSS_TIME_OUT_FIELD_NUMBER: _ClassVar[int]
    CNO_THRESH_NUM_SVS_FIELD_NUMBER: _ClassVar[int]
    CNO_THRESH_FIELD_NUMBER: _ClassVar[int]
    RESERVED1_FIELD_NUMBER: _ClassVar[int]
    STATIC_HOLD_MAX_DIST_FIELD_NUMBER: _ClassVar[int]
    UTC_STANDARD_FIELD_NUMBER: _ClassVar[int]
    RESERVED2_FIELD_NUMBER: _ClassVar[int]
    mask: int
    dyn_model: int
    fix_mode: int
    fixed_alt: int
    fixed_alt_var: int
    min_elev: int
    dr_limit: int
    p_dop: int
    t_dop: int
    p_acc: int
    t_acc: int
    static_hold_thresh: int
    dgnss_time_out: int
    cno_thresh_num_svs: int
    cno_thresh: int
    reserved1: _containers.RepeatedScalarFieldContainer[int]
    static_hold_max_dist: int
    utc_standard: int
    reserved2: _containers.RepeatedScalarFieldContainer[int]
    def __init__(self, mask: _Optional[int] = ..., dyn_model: _Optional[int] = ..., fix_mode: _Optional[int] = ..., fixed_alt: _Optional[int] = ..., fixed_alt_var: _Optional[int] = ..., min_elev: _Optional[int] = ..., dr_limit: _Optional[int] = ..., p_dop: _Optional[int] = ..., t_dop: _Optional[int] = ..., p_acc: _Optional[int] = ..., t_acc: _Optional[int] = ..., static_hold_thresh: _Optional[int] = ..., dgnss_time_out: _Optional[int] = ..., cno_thresh_num_svs: _Optional[int] = ..., cno_thresh: _Optional[int] = ..., reserved1: _Optional[_Iterable[int]] = ..., static_hold_max_dist: _Optional[int] = ..., utc_standard: _Optional[int] = ..., reserved2: _Optional[_Iterable[int]] = ...) -> None: ...



from make87_messages.core import header_pb2 as _header_pb2
from make87_messages_ros2.humble.sick_scan_xd.msg import radar_pre_header_device_block_pb2 as _radar_pre_header_device_block_pb2
from make87_messages_ros2.humble.sick_scan_xd.msg import radar_pre_header_encoder_block_pb2 as _radar_pre_header_encoder_block_pb2
from make87_messages_ros2.humble.sick_scan_xd.msg import radar_pre_header_measurement_param1_block_pb2 as _radar_pre_header_measurement_param1_block_pb2
from make87_messages_ros2.humble.sick_scan_xd.msg import radar_pre_header_status_block_pb2 as _radar_pre_header_status_block_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class RadarPreHeader(_message.Message):
    __slots__ = ["header", "uiversionno", "radarpreheaderdeviceblock", "radarpreheaderstatusblock", "radarpreheadermeasurementparam1block", "radarpreheaderarrayencoderblock"]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    UIVERSIONNO_FIELD_NUMBER: _ClassVar[int]
    RADARPREHEADERDEVICEBLOCK_FIELD_NUMBER: _ClassVar[int]
    RADARPREHEADERSTATUSBLOCK_FIELD_NUMBER: _ClassVar[int]
    RADARPREHEADERMEASUREMENTPARAM1BLOCK_FIELD_NUMBER: _ClassVar[int]
    RADARPREHEADERARRAYENCODERBLOCK_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    uiversionno: int
    radarpreheaderdeviceblock: _radar_pre_header_device_block_pb2.RadarPreHeaderDeviceBlock
    radarpreheaderstatusblock: _radar_pre_header_status_block_pb2.RadarPreHeaderStatusBlock
    radarpreheadermeasurementparam1block: _radar_pre_header_measurement_param1_block_pb2.RadarPreHeaderMeasurementParam1Block
    radarpreheaderarrayencoderblock: _containers.RepeatedCompositeFieldContainer[_radar_pre_header_encoder_block_pb2.RadarPreHeaderEncoderBlock]
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., uiversionno: _Optional[int] = ..., radarpreheaderdeviceblock: _Optional[_Union[_radar_pre_header_device_block_pb2.RadarPreHeaderDeviceBlock, _Mapping]] = ..., radarpreheaderstatusblock: _Optional[_Union[_radar_pre_header_status_block_pb2.RadarPreHeaderStatusBlock, _Mapping]] = ..., radarpreheadermeasurementparam1block: _Optional[_Union[_radar_pre_header_measurement_param1_block_pb2.RadarPreHeaderMeasurementParam1Block, _Mapping]] = ..., radarpreheaderarrayencoderblock: _Optional[_Iterable[_Union[_radar_pre_header_encoder_block_pb2.RadarPreHeaderEncoderBlock, _Mapping]]] = ...) -> None: ...



from make87_messages.core import header_pb2 as _header_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class GimbalManagerConfigureRequest(_message.Message):
    __slots__ = ["header", "sysid_primary", "compid_primary", "sysid_secondary", "compid_secondary", "gimbal_device_id"]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    SYSID_PRIMARY_FIELD_NUMBER: _ClassVar[int]
    COMPID_PRIMARY_FIELD_NUMBER: _ClassVar[int]
    SYSID_SECONDARY_FIELD_NUMBER: _ClassVar[int]
    COMPID_SECONDARY_FIELD_NUMBER: _ClassVar[int]
    GIMBAL_DEVICE_ID_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    sysid_primary: int
    compid_primary: int
    sysid_secondary: int
    compid_secondary: int
    gimbal_device_id: int
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., sysid_primary: _Optional[int] = ..., compid_primary: _Optional[int] = ..., sysid_secondary: _Optional[int] = ..., compid_secondary: _Optional[int] = ..., gimbal_device_id: _Optional[int] = ...) -> None: ...

class GimbalManagerConfigureResponse(_message.Message):
    __slots__ = ["header", "success", "result"]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    SUCCESS_FIELD_NUMBER: _ClassVar[int]
    RESULT_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    success: bool
    result: int
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., success: bool = ..., result: _Optional[int] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/ublox_ubx_interfaces/srv/hot_start.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nCmake87_messages_ros2/jazzy/ublox_ubx_interfaces/srv/hot_start.proto\x12\x33make87_messages_ros2.jazzy.ublox_ubx_interfaces.srv\"%\n\x0fHotStartRequest\x12\x12\n\nreset_type\x18\x01 \x01(\r\"\x12\n\x10HotStartResponseb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.ublox_ubx_interfaces.srv.hot_start_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_HOTSTARTREQUEST']._serialized_start=124
  _globals['_HOTSTARTREQUEST']._serialized_end=161
  _globals['_HOTSTARTRESPONSE']._serialized_start=163
  _globals['_HOTSTARTRESPONSE']._serialized_end=181
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/ros_gz_interfaces/msg/joint_wrench.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.geometry_msgs.msg import wrench_pb2 as make87__messages__ros2_dot_jazzy_dot_geometry__msgs_dot_msg_dot_wrench__pb2
from make87_messages_ros2.jazzy.std_msgs.msg import header_pb2 as make87__messages__ros2_dot_jazzy_dot_std__msgs_dot_msg_dot_header__pb2
from make87_messages_ros2.jazzy.std_msgs.msg import string_pb2 as make87__messages__ros2_dot_jazzy_dot_std__msgs_dot_msg_dot_string__pb2
from make87_messages_ros2.jazzy.std_msgs.msg import u_int32_pb2 as make87__messages__ros2_dot_jazzy_dot_std__msgs_dot_msg_dot_u__int32__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nCmake87_messages_ros2/jazzy/ros_gz_interfaces/msg/joint_wrench.proto\x12\x30make87_messages_ros2.jazzy.ros_gz_interfaces.msg\x1a\x39make87_messages_ros2/jazzy/geometry_msgs/msg/wrench.proto\x1a\x34make87_messages_ros2/jazzy/std_msgs/msg/header.proto\x1a\x34make87_messages_ros2/jazzy/std_msgs/msg/string.proto\x1a\x35make87_messages_ros2/jazzy/std_msgs/msg/u_int32.proto\"\xfc\x03\n\x0bJointWrench\x12?\n\x06header\x18\x01 \x01(\x0b\x32/.make87_messages_ros2.jazzy.std_msgs.msg.Header\x12\x44\n\x0b\x62ody_1_name\x18\x02 \x01(\x0b\x32/.make87_messages_ros2.jazzy.std_msgs.msg.String\x12\x42\n\tbody_1_id\x18\x03 \x01(\x0b\x32/.make87_messages_ros2.jazzy.std_msgs.msg.UInt32\x12\x44\n\x0b\x62ody_2_name\x18\x04 \x01(\x0b\x32/.make87_messages_ros2.jazzy.std_msgs.msg.String\x12\x42\n\tbody_2_id\x18\x05 \x01(\x0b\x32/.make87_messages_ros2.jazzy.std_msgs.msg.UInt32\x12K\n\rbody_1_wrench\x18\x06 \x01(\x0b\x32\x34.make87_messages_ros2.jazzy.geometry_msgs.msg.Wrench\x12K\n\rbody_2_wrench\x18\x07 \x01(\x0b\x32\x34.make87_messages_ros2.jazzy.geometry_msgs.msg.Wrenchb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.ros_gz_interfaces.msg.joint_wrench_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_JOINTWRENCH']._serialized_start=344
  _globals['_JOINTWRENCH']._serialized_end=852
# @@protoc_insertion_point(module_scope)



from make87_messages.core import header_pb2 as _header_pb2
from make87_messages_ros2.humble.soccer_vision_attribute_msgs.msg import confidence_pb2 as _confidence_pb2
from make87_messages_ros2.humble.vision_msgs.msg import point2_d_pb2 as _point2_d_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class MarkingIntersection(_message.Message):
    __slots__ = ["header", "center", "num_rays", "heading_rays", "confidence"]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    CENTER_FIELD_NUMBER: _ClassVar[int]
    NUM_RAYS_FIELD_NUMBER: _ClassVar[int]
    HEADING_RAYS_FIELD_NUMBER: _ClassVar[int]
    CONFIDENCE_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    center: _point2_d_pb2.Point2D
    num_rays: int
    heading_rays: _containers.RepeatedScalarFieldContainer[float]
    confidence: _confidence_pb2.Confidence
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., center: _Optional[_Union[_point2_d_pb2.Point2D, _Mapping]] = ..., num_rays: _Optional[int] = ..., heading_rays: _Optional[_Iterable[float]] = ..., confidence: _Optional[_Union[_confidence_pb2.Confidence, _Mapping]] = ...) -> None: ...



from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class Tunnel(_message.Message):
    __slots__ = ["target_system", "target_component", "payload_type", "payload_length", "payload"]
    TARGET_SYSTEM_FIELD_NUMBER: _ClassVar[int]
    TARGET_COMPONENT_FIELD_NUMBER: _ClassVar[int]
    PAYLOAD_TYPE_FIELD_NUMBER: _ClassVar[int]
    PAYLOAD_LENGTH_FIELD_NUMBER: _ClassVar[int]
    PAYLOAD_FIELD_NUMBER: _ClassVar[int]
    target_system: int
    target_component: int
    payload_type: int
    payload_length: int
    payload: _containers.RepeatedScalarFieldContainer[int]
    def __init__(self, target_system: _Optional[int] = ..., target_component: _Optional[int] = ..., payload_type: _Optional[int] = ..., payload_length: _Optional[int] = ..., payload: _Optional[_Iterable[int]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/py_trees_ros_interfaces/srv/close_snapshot_stream.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nTmake87_messages_ros2/rolling/py_trees_ros_interfaces/srv/close_snapshot_stream.proto\x12\x38make87_messages_ros2.rolling.py_trees_ros_interfaces.srv\"0\n\x1a\x43loseSnapshotStreamRequest\x12\x12\n\ntopic_name\x18\x01 \x01(\t\"-\n\x1b\x43loseSnapshotStreamResponse\x12\x0e\n\x06result\x18\x01 \x01(\x08\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.py_trees_ros_interfaces.srv.close_snapshot_stream_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_CLOSESNAPSHOTSTREAMREQUEST']._serialized_start=146
  _globals['_CLOSESNAPSHOTSTREAMREQUEST']._serialized_end=194
  _globals['_CLOSESNAPSHOTSTREAMRESPONSE']._serialized_start=196
  _globals['_CLOSESNAPSHOTSTREAMRESPONSE']._serialized_end=241
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/soccer_vision_3d_msgs/msg/ball.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.geometry_msgs.msg import point_pb2 as make87__messages__ros2_dot_jazzy_dot_geometry__msgs_dot_msg_dot_point__pb2
from make87_messages_ros2.jazzy.soccer_vision_attribute_msgs.msg import confidence_pb2 as make87__messages__ros2_dot_jazzy_dot_soccer__vision__attribute__msgs_dot_msg_dot_confidence__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n?make87_messages_ros2/jazzy/soccer_vision_3d_msgs/msg/ball.proto\x12\x34make87_messages_ros2.jazzy.soccer_vision_3d_msgs.msg\x1a\x38make87_messages_ros2/jazzy/geometry_msgs/msg/point.proto\x1aLmake87_messages_ros2/jazzy/soccer_vision_attribute_msgs/msg/confidence.proto\"\xa8\x01\n\x04\x42\x61ll\x12\x43\n\x06\x63\x65nter\x18\x01 \x01(\x0b\x32\x33.make87_messages_ros2.jazzy.geometry_msgs.msg.Point\x12[\n\nconfidence\x18\x02 \x01(\x0b\x32G.make87_messages_ros2.jazzy.soccer_vision_attribute_msgs.msg.Confidenceb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.soccer_vision_3d_msgs.msg.ball_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_BALL']._serialized_start=258
  _globals['_BALL']._serialized_end=426
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/rmf_fleet_msgs/msg/dock_summary.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.rolling.rmf_fleet_msgs.msg import dock_pb2 as make87__messages__ros2_dot_rolling_dot_rmf__fleet__msgs_dot_msg_dot_dock__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nBmake87_messages_ros2/rolling/rmf_fleet_msgs/msg/dock_summary.proto\x12/make87_messages_ros2.rolling.rmf_fleet_msgs.msg\x1a:make87_messages_ros2/rolling/rmf_fleet_msgs/msg/dock.proto\"S\n\x0b\x44ockSummary\x12\x44\n\x05\x64ocks\x18\x01 \x03(\x0b\x32\x35.make87_messages_ros2.rolling.rmf_fleet_msgs.msg.Dockb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.rmf_fleet_msgs.msg.dock_summary_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_DOCKSUMMARY']._serialized_start=179
  _globals['_DOCKSUMMARY']._serialized_end=262
# @@protoc_insertion_point(module_scope)



from make87_messages_ros2.rolling.geometry_msgs.msg import twist_pb2 as _twist_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class TwistWithCovariance(_message.Message):
    __slots__ = ["twist", "covariance"]
    TWIST_FIELD_NUMBER: _ClassVar[int]
    COVARIANCE_FIELD_NUMBER: _ClassVar[int]
    twist: _twist_pb2.Twist
    covariance: _containers.RepeatedScalarFieldContainer[float]
    def __init__(self, twist: _Optional[_Union[_twist_pb2.Twist, _Mapping]] = ..., covariance: _Optional[_Iterable[float]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/composition_interfaces/srv/load_node.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.rcl_interfaces.msg import parameter_pb2 as make87__messages__ros2_dot_jazzy_dot_rcl__interfaces_dot_msg_dot_parameter__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nEmake87_messages_ros2/jazzy/composition_interfaces/srv/load_node.proto\x12\x35make87_messages_ros2.jazzy.composition_interfaces.srv\x1a=make87_messages_ros2/jazzy/rcl_interfaces/msg/parameter.proto\"\xb0\x02\n\x0fLoadNodeRequest\x12\x14\n\x0cpackage_name\x18\x01 \x01(\t\x12\x13\n\x0bplugin_name\x18\x02 \x01(\t\x12\x11\n\tnode_name\x18\x03 \x01(\t\x12\x16\n\x0enode_namespace\x18\x04 \x01(\t\x12\x11\n\tlog_level\x18\x05 \x01(\r\x12\x13\n\x0bremap_rules\x18\x06 \x03(\t\x12L\n\nparameters\x18\x07 \x03(\x0b\x32\x38.make87_messages_ros2.jazzy.rcl_interfaces.msg.Parameter\x12Q\n\x0f\x65xtra_arguments\x18\x08 \x03(\x0b\x32\x38.make87_messages_ros2.jazzy.rcl_interfaces.msg.Parameter\"e\n\x10LoadNodeResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x15\n\rerror_message\x18\x02 \x01(\t\x12\x16\n\x0e\x66ull_node_name\x18\x03 \x01(\t\x12\x11\n\tunique_id\x18\x04 \x01(\x04\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.composition_interfaces.srv.load_node_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_LOADNODEREQUEST']._serialized_start=192
  _globals['_LOADNODEREQUEST']._serialized_end=496
  _globals['_LOADNODERESPONSE']._serialized_start=498
  _globals['_LOADNODERESPONSE']._serialized_end=599
# @@protoc_insertion_point(module_scope)



from make87_messages_ros2.rolling.moveit_msgs.msg import motion_plan_request_pb2 as _motion_plan_request_pb2
from make87_messages_ros2.rolling.moveit_msgs.msg import motion_plan_response_pb2 as _motion_plan_response_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class PipelineState(_message.Message):
    __slots__ = ["request", "response", "pipeline_stage"]
    REQUEST_FIELD_NUMBER: _ClassVar[int]
    RESPONSE_FIELD_NUMBER: _ClassVar[int]
    PIPELINE_STAGE_FIELD_NUMBER: _ClassVar[int]
    request: _motion_plan_request_pb2.MotionPlanRequest
    response: _motion_plan_response_pb2.MotionPlanResponse
    pipeline_stage: str
    def __init__(self, request: _Optional[_Union[_motion_plan_request_pb2.MotionPlanRequest, _Mapping]] = ..., response: _Optional[_Union[_motion_plan_response_pb2.MotionPlanResponse, _Mapping]] = ..., pipeline_stage: _Optional[str] = ...) -> None: ...



from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class TeleportRelativeRequest(_message.Message):
    __slots__ = ["linear", "angular"]
    LINEAR_FIELD_NUMBER: _ClassVar[int]
    ANGULAR_FIELD_NUMBER: _ClassVar[int]
    linear: float
    angular: float
    def __init__(self, linear: _Optional[float] = ..., angular: _Optional[float] = ...) -> None: ...

class TeleportRelativeResponse(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/gazebo_msgs/srv/get_world_properties.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nEmake87_messages_ros2/jazzy/gazebo_msgs/srv/get_world_properties.proto\x12*make87_messages_ros2.jazzy.gazebo_msgs.srv\"\x1b\n\x19GetWorldPropertiesRequest\"\x87\x01\n\x1aGetWorldPropertiesResponse\x12\x10\n\x08sim_time\x18\x01 \x01(\x01\x12\x13\n\x0bmodel_names\x18\x02 \x03(\t\x12\x19\n\x11rendering_enabled\x18\x03 \x01(\x08\x12\x0f\n\x07success\x18\x04 \x01(\x08\x12\x16\n\x0estatus_message\x18\x05 \x01(\tb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.gazebo_msgs.srv.get_world_properties_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_GETWORLDPROPERTIESREQUEST']._serialized_start=117
  _globals['_GETWORLDPROPERTIESREQUEST']._serialized_end=144
  _globals['_GETWORLDPROPERTIESRESPONSE']._serialized_start=147
  _globals['_GETWORLDPROPERTIESRESPONSE']._serialized_end=282
# @@protoc_insertion_point(module_scope)



from make87_messages.core import header_pb2 as _header_pb2
from make87_messages_ros2.humble.geometry_msgs.msg import pose_with_covariance_stamped_pb2 as _pose_with_covariance_stamped_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class SetPoseRequest(_message.Message):
    __slots__ = ["header", "pose"]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    POSE_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    pose: _pose_with_covariance_stamped_pb2.PoseWithCovarianceStamped
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., pose: _Optional[_Union[_pose_with_covariance_stamped_pb2.PoseWithCovarianceStamped, _Mapping]] = ...) -> None: ...

class SetPoseResponse(_message.Message):
    __slots__ = ["header"]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ...) -> None: ...



from make87_messages_ros2.rolling.diagnostic_msgs.msg import diagnostic_status_pb2 as _diagnostic_status_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class SelfTestRequest(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class SelfTestResponse(_message.Message):
    __slots__ = ["id", "passed", "status"]
    ID_FIELD_NUMBER: _ClassVar[int]
    PASSED_FIELD_NUMBER: _ClassVar[int]
    STATUS_FIELD_NUMBER: _ClassVar[int]
    id: str
    passed: int
    status: _containers.RepeatedCompositeFieldContainer[_diagnostic_status_pb2.DiagnosticStatus]
    def __init__(self, id: _Optional[str] = ..., passed: _Optional[int] = ..., status: _Optional[_Iterable[_Union[_diagnostic_status_pb2.DiagnosticStatus, _Mapping]]] = ...) -> None: ...



from make87_messages_ros2.jazzy.gazebo_msgs.msg import entity_state_pb2 as _entity_state_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class SetEntityStateRequest(_message.Message):
    __slots__ = ["state"]
    STATE_FIELD_NUMBER: _ClassVar[int]
    state: _entity_state_pb2.EntityState
    def __init__(self, state: _Optional[_Union[_entity_state_pb2.EntityState, _Mapping]] = ...) -> None: ...

class SetEntityStateResponse(_message.Message):
    __slots__ = ["success"]
    SUCCESS_FIELD_NUMBER: _ClassVar[int]
    success: bool
    def __init__(self, success: bool = ...) -> None: ...



from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class AddTwoIntsRequest(_message.Message):
    __slots__ = ["a", "b"]
    A_FIELD_NUMBER: _ClassVar[int]
    B_FIELD_NUMBER: _ClassVar[int]
    a: int
    b: int
    def __init__(self, a: _Optional[int] = ..., b: _Optional[int] = ...) -> None: ...

class AddTwoIntsResponse(_message.Message):
    __slots__ = ["sum"]
    SUM_FIELD_NUMBER: _ClassVar[int]
    sum: int
    def __init__(self, sum: _Optional[int] = ...) -> None: ...



from make87_messages.core import header_pb2 as _header_pb2
from make87_messages_ros2.humble.std_msgs.msg import header_pb2 as _header_pb2_1
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Information(_message.Message):
    __slots__ = ["header", "ros2_header", "sensor_type", "hw_temperature", "sensor_blind", "sw_fail", "hw_fail", "can_fail", "config_fail", "diag_mode", "dtc", "dtc_order_id", "sensor_not_safe"]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    ROS2_HEADER_FIELD_NUMBER: _ClassVar[int]
    SENSOR_TYPE_FIELD_NUMBER: _ClassVar[int]
    HW_TEMPERATURE_FIELD_NUMBER: _ClassVar[int]
    SENSOR_BLIND_FIELD_NUMBER: _ClassVar[int]
    SW_FAIL_FIELD_NUMBER: _ClassVar[int]
    HW_FAIL_FIELD_NUMBER: _ClassVar[int]
    CAN_FAIL_FIELD_NUMBER: _ClassVar[int]
    CONFIG_FAIL_FIELD_NUMBER: _ClassVar[int]
    DIAG_MODE_FIELD_NUMBER: _ClassVar[int]
    DTC_FIELD_NUMBER: _ClassVar[int]
    DTC_ORDER_ID_FIELD_NUMBER: _ClassVar[int]
    SENSOR_NOT_SAFE_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    ros2_header: _header_pb2_1.Header
    sensor_type: int
    hw_temperature: float
    sensor_blind: bool
    sw_fail: bool
    hw_fail: bool
    can_fail: bool
    config_fail: bool
    diag_mode: bool
    dtc: int
    dtc_order_id: int
    sensor_not_safe: bool
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., ros2_header: _Optional[_Union[_header_pb2_1.Header, _Mapping]] = ..., sensor_type: _Optional[int] = ..., hw_temperature: _Optional[float] = ..., sensor_blind: bool = ..., sw_fail: bool = ..., hw_fail: bool = ..., can_fail: bool = ..., config_fail: bool = ..., diag_mode: bool = ..., dtc: _Optional[int] = ..., dtc_order_id: _Optional[int] = ..., sensor_not_safe: bool = ...) -> None: ...
